@@ -27,6 +27,24 @@ def build_folder_uri(folder_name: str) -> str:
     return f"gaia://{tenant_id}/{folder_name}"
 
 
+def create_destination_directory(file_path: str) -> Path:
+    file_split = file_path.split('/')
+    file_split.pop()
+    if len(file_split) > 0:
+        parent_folder = "/".join(file_split)
+        destination_folder = Path(tempfile.gettempdir()) / parent_folder
+        if not os.path.exists(destination_folder):
+            mode = 0o777
+            os.makedirs(destination_folder, mode)
+        return destination_folder
+    return Path(tempfile.gettempdir())
+
+
+def extract_file_name(file_path: str) -> Path:
+    file_split = file_path.split('/')
+    return file_split.pop()
+
+
 class DataApiDownloader(Downloader):
 
     def __init__(self, gaia_ref: GaiaRef):
@@ -88,15 +106,14 @@ class DataApiDownloader(Downloader):
         except Exception as exc:
             logger.error("File could not be downloaded from data API")
             raise exc
-        dest_file_path = Path(tempfile.gettempdir()) / file_name
+
+        dest_file_path = create_destination_directory(file_name) / extract_file_name(file_name)
 
         with open(dest_file_path, mode='wb') as file:
             file.write(downloaded_file_in_bytes)
         logger.info(f"file was successfully downloaded under {dest_file_path}")
         return dest_file_path
 
-
-
     def download_folder(self, folder_name: str) -> List[Path]:
         """
          It downloads the files which are hosted under the provided folder_name in AIOS dataApi. Files are downloaded
